==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebBaseAlertLikeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebBaseAlertLikeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseAlertLikeDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseAlertLikeDescriptionMetadata.a == null) {
                WebBaseAlertLikeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseAlertLikeDescriptionMetadata.c(WebBaseAlertLikeDescriptionMetadata.a);
            }
            if (a.k(WebBaseAlertLikeDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebBaseAlertLikeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseAlertLike");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("DisplayTime", "Number:double");
            a.item("KeepOpen", "Boolean");
            a.item("Position", "ExportedType:string:BaseAlertLikePosition");
            a.item("Position@stringUnion", "WebComponents;React");
            a.item("Position@names", "Bottom;Middle;Top");
        }
        static d(a) {
            WebBaseAlertLikeDescriptionMetadata.b(a);
            a.ac("WebBaseAlertLike", WebBaseAlertLikeDescriptionMetadata.a);
        }
    }
    WebBaseAlertLikeDescriptionMetadata.$t = markType(WebBaseAlertLikeDescriptionMetadata, 'WebBaseAlertLikeDescriptionMetadata');
    WebBaseAlertLikeDescriptionMetadata.a = null;
    return WebBaseAlertLikeDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebBaseAlertLikeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebBaseAlertLikeDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebBaseAlertLikeDescriptionMetadata extends Base {
        static b(a) {
            if (WebBaseAlertLikeDescriptionMetadata.a == null) {
                WebBaseAlertLikeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebBaseAlertLikeDescriptionMetadata.c(WebBaseAlertLikeDescriptionMetadata.a);
            }
            if (a.k(WebBaseAlertLikeDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebBaseAlertLikeDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:BaseAlertLike");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("DisplayTime", "Number:double");
            a.item("KeepOpen", "Boolean");
            a.item("Position", "ExportedType:string:AbsolutePosition");
            a.item("Position@stringUnion", "WebComponents;React");
            a.item("Position@names", "Bottom;Middle;Top");
        }
        static d(a) {
            WebBaseAlertLikeDescriptionMetadata.b(a);
            a.ad("WebBaseAlertLike", WebBaseAlertLikeDescriptionMetadata.a);
        }
    }
    WebBaseAlertLikeDescriptionMetadata.$t = markType(WebBaseAlertLikeDescriptionMetadata, 'WebBaseAlertLikeDescriptionMetadata');
    WebBaseAlertLikeDescriptionMetadata.a = null;
    return WebBaseAlertLikeDescriptionMetadata;
})();
